summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/tools/observinglist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/tools/observinglist.cpp')
-rw-r--r--kstars/kstars/tools/observinglist.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/kstars/kstars/tools/observinglist.cpp b/kstars/kstars/tools/observinglist.cpp
index fbd1702c..163040b9 100644
--- a/kstars/kstars/tools/observinglist.cpp
+++ b/kstars/kstars/tools/observinglist.cpp
@@ -53,9 +53,9 @@
#include "devicemanager.h"
#include "indistd.h"
-ObservingList::ObservingList( KStars *_ks, TQWidget* parent )
+ObservingList::ObservingList( KStars *_ks, TQWidget* tqparent )
: KDialogBase( KDialogBase::Plain, i18n( "Observing List" ),
- Close, Close, parent, "observinglist", false ), ks( _ks ), LogObject(0), oCurrent(0),
+ Close, Close, tqparent, "observinglist", false ), ks( _ks ), LogObject(0), oCurrent(0),
noNameStars(0), isModified(false), bIsLarge(true)
{
TQFrame *page = plainPage();
@@ -121,7 +121,7 @@ ObservingList::ObservingList( KStars *_ks, TQWidget* parent )
ui->NotesEdit->setEnabled( false );
}
-bool ObservingList::contains( const SkyObject *q ) {
+bool ObservingList::tqcontains( const SkyObject *q ) {
for ( SkyObject* o = obsList.first(); o; o = obsList.next() ) {
if ( o == q ) return true;
}
@@ -144,7 +144,7 @@ void ObservingList::slotAddObject( SkyObject *obj ) {
for ( SkyObject *o = obsList.first(); o; o = obsList.next() ) {
if ( obj == o ) {
//FIXME STRINGS FREEZE
- //ks->statusBar()->changeItem( i18n( "%1 is already in the observing list." ).arg( obj->name() ), 0 );
+ //ks->statusBar()->changeItem( i18n( "%1 is already in the observing list." ).tqarg( obj->name() ), 0 );
return;
}
}
@@ -164,7 +164,7 @@ void ObservingList::slotAddObject( SkyObject *obj ) {
ui->TinyTable->insertItem( obj->translatedName() );
//Note addition in statusbar
- ks->statusBar()->changeItem( i18n( "Added %1 to observing list." ).arg( obj->name() ), 0 );
+ ks->statusBar()->changeItem( i18n( "Added %1 to observing list." ).tqarg( obj->name() ), 0 );
}
void ObservingList::slotRemoveObject( SkyObject *o ) {
@@ -200,7 +200,7 @@ void ObservingList::slotRemoveObject( SkyObject *o ) {
}
if ( ! objectFound ) {
- kdDebug() << i18n( "Cannot remove Object %1; not found in table." ).arg(o->translatedName()) << endl;
+ kdDebug() << i18n( "Cannot remove Object %1; not found in table." ).tqarg(o->translatedName()) << endl;
} else {
//Remove object from TinyTable
for ( uint i=0; i < ui->TinyTable->count(); i++ ) {
@@ -268,7 +268,7 @@ void ObservingList::slotNewSelection() {
}
if ( ! found ) {
- kdDebug() << i18n( "Object %1 not found in obsList." ).arg( newName ) << endl;
+ kdDebug() << i18n( "Object %1 not found in obsList." ).tqarg( newName ) << endl;
} else if ( newName != i18n( "star" ) ) {
//Display the object's current user notes in the NotesEdit
//First, save the last object's user log to disk, if necessary
@@ -280,9 +280,9 @@ void ObservingList::slotNewSelection() {
ui->NotesLabel->setEnabled( true );
ui->NotesEdit->setEnabled( true );
- ui->NotesLabel->setText( i18n( "observing notes for %1:" ).arg( LogObject->translatedName() ) );
+ ui->NotesLabel->setText( i18n( "observing notes for %1:" ).tqarg( LogObject->translatedName() ) );
if ( LogObject->userLog.isEmpty() ) {
- ui->NotesEdit->setText( i18n("Record here observation logs and/or data on %1.").arg( LogObject->translatedName() ) );
+ ui->NotesEdit->setText( i18n("Record here observation logs and/or data on %1.").tqarg( LogObject->translatedName() ) );
} else {
ui->NotesEdit->setText( LogObject->userLog );
}
@@ -345,8 +345,8 @@ void ObservingList::slotSlewToObject()
int selectedCoord(0);
SkyPoint sp;
// Find the first device with EQUATORIAL_EOD_COORD or EQUATORIAL_COORD and with SLEW element
// i.e. the first telescope we find!
INDIMenu *imenu = ks->getINDIMenu();
@@ -357,10 +357,10 @@ void ObservingList::slotSlewToObject()
{
indidev = imenu->mgr.at(i)->indi_dev.at(j);
indidev->stdDev->currentObject = NULL;
- prop = indidev->findProp("EQUATORIAL_EOD_COORD");
+ prop = indidev->findProp("ETQUATORIAL_EOD_COORD");
if (prop == NULL)
{
- prop = indidev->findProp("EQUATORIAL_COORD");
+ prop = indidev->findProp("ETQUATORIAL_COORD");
if (prop == NULL)
{
prop = indidev->findProp("HORIZONTAL_COORD");
@@ -378,7 +378,7 @@ void ObservingList::slotSlewToObject()
if (ConnectEle->state == PS_OFF)
{
- KMessageBox::error(0, i18n("Telescope %1 is offline. Please connect and retry again.").arg(indidev->label));
+ KMessageBox::error(0, i18n("Telescope %1 is offline. Please connect and retry again.").tqarg(indidev->label));
return;
}
@@ -393,7 +393,7 @@ void ObservingList::slotSlewToObject()
if (!DecEle) continue;
break;
- // Horizontal
+ //Qt::Horizontal
case 1:
if (prop->perm == PP_RO) continue;
AzEle = prop->findElement("AZ");
@@ -430,10 +430,10 @@ void ObservingList::slotSlewToObject()
sp.set (ks->map()->clickedPoint()->ra(), ks->map()->clickedPoint()->dec());
if (useJ2000)
- sp.apparentCoord(ks->data()->ut().djd(), (long double) J2000);
+ sp.aptqparentCoord(ks->data()->ut().djd(), (long double) J2000);
- RAEle->write_w->setText(TQString("%1:%2:%3").arg(sp.ra()->hour()).arg(sp.ra()->minute()).arg(sp.ra()->second()));
- DecEle->write_w->setText(TQString("%1:%2:%3").arg(sp.dec()->degree()).arg(sp.dec()->arcmin()).arg(sp.dec()->arcsec()));
+ RAEle->write_w->setText(TQString("%1:%2:%3").tqarg(sp.ra()->hour()).tqarg(sp.ra()->minute()).tqarg(sp.ra()->second()));
+ DecEle->write_w->setText(TQString("%1:%2:%3").tqarg(sp.dec()->degree()).tqarg(sp.dec()->arcmin()).tqarg(sp.dec()->arcsec()));
break;
@@ -449,8 +449,8 @@ void ObservingList::slotSlewToObject()
sp.setAlt(*ks->map()->clickedPoint()->alt());
}
- AzEle->write_w->setText(TQString("%1:%2:%3").arg(sp.az()->degree()).arg(sp.az()->arcmin()).arg(sp.az()->arcsec()));
- AltEle->write_w->setText(TQString("%1:%2:%3").arg(sp.alt()->degree()).arg(sp.alt()->arcmin()).arg(sp.alt()->arcsec()));
+ AzEle->write_w->setText(TQString("%1:%2:%3").tqarg(sp.az()->degree()).tqarg(sp.az()->arcmin()).tqarg(sp.az()->arcsec()));
+ AltEle->write_w->setText(TQString("%1:%2:%3").tqarg(sp.alt()->degree()).tqarg(sp.alt()->arcmin()).tqarg(sp.alt()->arcsec()));
break;
}
@@ -490,7 +490,7 @@ void ObservingList::slotAVT() {
void ObservingList::slotClose() {
//Save the current User log text
if ( oCurrent && ! ui->NotesEdit->text().isEmpty() && ui->NotesEdit->text()
- != i18n("Record here observation logs and/or data on %1.").arg( oCurrent->name()) ) {
+ != i18n("Record here observation logs and/or data on %1.").tqarg( oCurrent->name()) ) {
oCurrent->saveUserLog( ui->NotesEdit->text() );
}
@@ -500,7 +500,7 @@ void ObservingList::slotClose() {
void ObservingList::saveCurrentUserLog() {
if ( ! ui->NotesEdit->text().isEmpty() &&
ui->NotesEdit->text() !=
- i18n("Record here observation logs and/or data on %1.").arg( LogObject->translatedName() ) ) {
+ i18n("Record here observation logs and/or data on %1.").tqarg( LogObject->translatedName() ) ) {
LogObject->saveUserLog( ui->NotesEdit->text() );
ui->NotesEdit->clear();
@@ -528,7 +528,7 @@ void ObservingList::slotOpenList() {
}
if ( !f.open( IO_ReadOnly) ) {
- TQString message = i18n( "Could not open file %1" ).arg( f.name() );
+ TQString message = i18n( "Could not open file %1" ).tqarg( f.name() );
KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
return;
}
@@ -627,7 +627,7 @@ void ObservingList::slotSaveList() {
TQFile f( FileName );
if ( !f.open( IO_WriteOnly) ) {
- TQString message = i18n( "Could not open file %1. Try a different filename?" ).arg( f.name() );
+ TQString message = i18n( "Could not open file %1. Try a different filename?" ).tqarg( f.name() );
if ( KMessageBox::warningYesNo( 0, message, i18n( "Could Not Open File" ), i18n("Try Different"), i18n("Do Not Try") ) == KMessageBox::Yes ) {
FileName == "";
@@ -345,8 +345,8 @@ void ObservingList::slotSlewToObject()
int selectedCoord(0);
SkyPoint sp;
- // Find the first device with EQUATORIAL_EOD_COORD or EQUATORIAL_COORD and with SLEW element
- // i.e. the first telescope we find!
+ // Find the first device with ETQUATORIAL_EOD_COORD or ETQUATORIAL_COORD and with SLEW element
+ // i.e. the first telescope we tqfind!
INDIMenu *imenu = ks->getINDIMenu();